import { PlayerEventType } from 'react-native-theoplayer';
import { useEffect, useRef } from 'react';
import { YouboraConnector } from '../YouboraConnector';
export function useYoubora(options, logLevel) {
  const connector = useRef();
  const theoPlayer = useRef();
  const initialize = player => {
    // Optionally destroy existent connector
    onDestroy();
    theoPlayer.current = player;
    if (player) {
      connector.current = new YouboraConnector(player, options, logLevel);
      player.addEventListener(PlayerEventType.DESTROY, onDestroy);
    } else {
      throw new Error('Invalid THEOplayer instance');
    }
  };
  const onDestroy = () => {
    if (connector.current) {
      if (!theoPlayer.current) {
        throw new Error('Invalid THEOplayer instance');
      }
      theoPlayer.current.removeEventListener(PlayerEventType.DESTROY, onDestroy);
      connector.current.destroy();
      connector.current = undefined;
    }
  };
  useEffect(() => {
    return onDestroy;
  }, []);
  return [connector, initialize];
}
//# sourceMappingURL=useYoubora.js.map